@@ -4,12 +4,12 @@ import os
 from airflow.models.dag import DAG
 from airflow.operators.bash_operator import BashOperator
 from airflow.utils.dates import days_ago
-from dagster_airflow.dagster_pipeline_factory import make_dagster_pipeline_from_airflow_dag
-
-from dagster import DagsterEventType, DagsterInstance, execute_pipeline
+from dagster import DagsterEventType, execute_pipeline
 from dagster.core.instance import AIRFLOW_EXECUTION_DATE_STR
 from dagster.core.storage.compute_log_manager import ComputeIOType
+from dagster.core.test_utils import instance_for_test
 from dagster.seven import get_current_datetime_in_utc
+from dagster_airflow.dagster_pipeline_factory import make_dagster_pipeline_from_airflow_dag
 
 default_args = {
     "owner": "dagster",
@@ -82,51 +82,51 @@ def get_dag():
 def test_pipeline_tags():
     dag = get_dag()
 
-    instance = DagsterInstance.local_temp()
-    manager = instance.compute_log_manager
+    with instance_for_test() as instance:
+        manager = instance.compute_log_manager
 
-    # When mode is default and tags are set, run with tags
-    result = execute_pipeline(
-        pipeline=make_dagster_pipeline_from_airflow_dag(
-            dag=dag, tags={AIRFLOW_EXECUTION_DATE_STR: EXECUTION_DATE_MINUS_WEEK_FMT}
-        ),
-        instance=instance,
-    )
-    check_compute_logs(manager, result, EXECUTION_DATE_MINUS_WEEK_FMT)
+        # When mode is default and tags are set, run with tags
+        result = execute_pipeline(
+            pipeline=make_dagster_pipeline_from_airflow_dag(
+                dag=dag, tags={AIRFLOW_EXECUTION_DATE_STR: EXECUTION_DATE_MINUS_WEEK_FMT}
+            ),
+            instance=instance,
+        )
+        check_compute_logs(manager, result, EXECUTION_DATE_MINUS_WEEK_FMT)
 
 
 def test_pipeline_auto_tag():
     dag = get_dag()
 
-    instance = DagsterInstance.local_temp()
-    manager = instance.compute_log_manager
+    with instance_for_test() as instance:
+        manager = instance.compute_log_manager
 
-    pre_execute_time = get_current_datetime_in_utc()
+        pre_execute_time = get_current_datetime_in_utc()
 
-    # When tags are not set, run with current time
-    result = execute_pipeline(
-        pipeline=make_dagster_pipeline_from_airflow_dag(dag=dag), instance=instance,
-    )
+        # When tags are not set, run with current time
+        result = execute_pipeline(
+            pipeline=make_dagster_pipeline_from_airflow_dag(dag=dag), instance=instance,
+        )
 
-    post_execute_time = get_current_datetime_in_utc()
+        post_execute_time = get_current_datetime_in_utc()
 
-    compute_io_path = manager.get_local_path(
-        result.run_id, "airflow_templated.compute", ComputeIOType.STDOUT
-    )
-    assert os.path.exists(compute_io_path)
-    stdout_file = open(compute_io_path, "r")
-    file_contents = normalize_file_content(stdout_file.read())
+        compute_io_path = manager.get_local_path(
+            result.run_id, "airflow_templated.compute", ComputeIOType.STDOUT
+        )
+        assert os.path.exists(compute_io_path)
+        stdout_file = open(compute_io_path, "r")
+        file_contents = normalize_file_content(stdout_file.read())
 
-    stdout_file.close()
+        stdout_file.close()
 
-    search_str = "INFO - Running command: \n    echo '"
-    date_start = file_contents.find(search_str) + len(search_str)
-    date_end = date_start + 10  # number of characters in YYYY-MM-DD
-    date = file_contents[date_start:date_end]
+        search_str = "INFO - Running command: \n    echo '"
+        date_start = file_contents.find(search_str) + len(search_str)
+        date_end = date_start + 10  # number of characters in YYYY-MM-DD
+        date = file_contents[date_start:date_end]
 
-    check_compute_logs(manager, result, date)
+        check_compute_logs(manager, result, date)
 
-    pre_execute_time_fmt = pre_execute_time.strftime("%Y-%m-%d")
-    post_execute_time_fmt = post_execute_time.strftime("%Y-%m-%d")
+        pre_execute_time_fmt = pre_execute_time.strftime("%Y-%m-%d")
+        post_execute_time_fmt = post_execute_time.strftime("%Y-%m-%d")
 
-    assert date in [pre_execute_time_fmt, post_execute_time_fmt]
+        assert date in [pre_execute_time_fmt, post_execute_time_fmt]
