@@ -1,20 +1,19 @@
 from airflow.exceptions import AirflowSkipException
-
 from dagster.core.events.log import DagsterEventRecord
 
 
 def validate_pipeline_execution(pipeline_exc_result):
     expected_airflow_demo_events = {
-        ('STEP_START', 'multiply_the_word.compute'),
-        ('STEP_INPUT', 'multiply_the_word.compute'),
-        ('STEP_OUTPUT', 'multiply_the_word.compute'),
-        ('OBJECT_STORE_OPERATION', 'multiply_the_word.compute'),
-        ('STEP_SUCCESS', 'multiply_the_word.compute'),
-        ('STEP_START', 'count_letters.compute'),
-        ('OBJECT_STORE_OPERATION', 'count_letters.compute'),
-        ('STEP_INPUT', 'count_letters.compute'),
-        ('STEP_OUTPUT', 'count_letters.compute'),
-        ('STEP_SUCCESS', 'count_letters.compute'),
+        ("STEP_START", "multiply_the_word.compute"),
+        ("STEP_INPUT", "multiply_the_word.compute"),
+        ("STEP_OUTPUT", "multiply_the_word.compute"),
+        ("OBJECT_STORE_OPERATION", "multiply_the_word.compute"),
+        ("STEP_SUCCESS", "multiply_the_word.compute"),
+        ("STEP_START", "count_letters.compute"),
+        ("OBJECT_STORE_OPERATION", "count_letters.compute"),
+        ("STEP_INPUT", "count_letters.compute"),
+        ("STEP_OUTPUT", "count_letters.compute"),
+        ("STEP_SUCCESS", "count_letters.compute"),
     }
 
     seen_events = set()
@@ -32,10 +31,10 @@ def validate_pipeline_execution(pipeline_exc_result):
 
 def validate_skip_pipeline_execution(result):
     expected_airflow_task_states = {
-        ('foo', False),
-        ('first_consumer', False),
-        ('second_consumer', True),
-        ('third_consumer', True),
+        ("foo", False),
+        ("first_consumer", False),
+        ("second_consumer", True),
+        ("third_consumer", True),
     }
 
     seen_events = {
